@@ -36,7 +36,7 @@ class DataSource(BaseModel):
     instrument_type: str = None
     source_type: str = None
     display_name: str = None
-    metadata: str = None
+    metadata: Dict = {}
     owner: str = None
     maintainers: List[str] = []
     ephemeris_metadata_schema: List[Dict] = []
@@ -267,7 +267,6 @@ def add(data_source: DataSource) -> DataSource:
     """
 
     # do request
-    # TODO: Check again after fix for null schema values
     request_data = {
         "program": data_source.program,
         "platform": data_source.platform,
@@ -276,7 +275,7 @@ def add(data_source: DataSource) -> DataSource:
         "display_name": data_source.display_name,
         "ephemeris_metadata_schema": data_source.ephemeris_metadata_schema,
         "data_product_metadata_schema": data_source.data_product_metadata_schema,
-        "maintainers": data_source.maintainers,
+        "metadata": data_source.metadata
     }
 
     if (data_source.identifier is not None):
@@ -344,7 +343,6 @@ def update(data_source: DataSource) -> DataSource:
     :return: updated data source
     :rtype: aurorax.sources.DataSource
     """
-    # TODO: Check for not-None schema fields too?
     if not all([data_source.identifier, data_source.program, data_source.platform, data_source.instrument_type, data_source.source_type, data_source.display_name]):
         raise aurorax.AuroraXBadParametersException("One or more required data source fields are missing. Update operation aborted.")
 
